@@ -1,6 +1,6 @@
 __author__ = "Filipe Ximenes, Andrey Ilin"
 __email__ = "andreyilin@fastmail.com"
-__version__ = "4.0.2"
+__version__ = "4.1.1"
 
 
 from .adapters import (
@@ -14,13 +14,20 @@ from .adapters import (
     TapiocaAdapterXML,
     TapiocaAdapterXMLMixin,
 )
+from .client import (
+    ProcessData,
+    TapiocaClient,
+    TapiocaClientExecutor,
+    TapiocaClientResource,
+    TapiocaClientResponse,
+)
 from .exceptions import (
     ClientError,
     ResponseProcessException,
     ServerError,
     TapiocaException,
 )
-from .generate import generate_wrapper_from_adapter
+from .generate import TapiocaInstantiator, generate_wrapper_from_adapter
 from .serializers import BaseSerializer, SimpleSerializer
 
 __all__ = (
@@ -33,10 +40,16 @@ __all__ = (
     "TapiocaAdapterPydanticMixin",
     "TapiocaAdapterXML",
     "TapiocaAdapterXMLMixin",
+    "ProcessData",
+    "TapiocaClient",
+    "TapiocaClientExecutor",
+    "TapiocaClientResource",
+    "TapiocaClientResponse",
     "ClientError",
     "ResponseProcessException",
     "ServerError",
     "TapiocaException",
+    "TapiocaInstantiator",
     "generate_wrapper_from_adapter",
     "BaseSerializer",
     "SimpleSerializer",
